@@ -66,6 +66,7 @@
 //!     &img_timestep_range,
 //!     &img_coarse_chan_range,
 //!     Some(flag_array),
+//!     false,
 //! ).unwrap();
 //!
 //! // write the flags to disk as .mwaf
@@ -89,6 +90,7 @@
 //!     None,
 //!     1,
 //!     1,
+//!     false,
 //! ).unwrap();
 //! ```
 //!
@@ -278,7 +280,8 @@ macro_rules! _write_hdu_buffer_to_jones_view {
 ///     &context,
 ///     &img_timestep_range,
 ///     &img_coarse_chan_range,
-///     None
+///     None,
+///     false,
 /// ).unwrap();
 ///
 /// let dims_common = jones_array.dim();
@@ -288,7 +291,8 @@ macro_rules! _write_hdu_buffer_to_jones_view {
 ///     &context,
 ///     &good_timestep_range,
 ///     &img_coarse_chan_range,
-///     None
+///     None,
+///     false,
 /// ).unwrap();
 ///
 /// let dims_good = jones_array.dim();
@@ -304,9 +308,8 @@ pub fn context_to_jones_array(
     context: &CorrelatorContext,
     mwalib_timestep_range: &Range<usize>,
     mwalib_coarse_chan_range: &Range<usize>,
-    // TODO: allow subset of baselines
-    // mwalib_baseline_idxs: &[usize],
     flag_array: Option<Array3<bool>>,
+    draw_progress: bool,
 ) -> Result<(Array3<Jones<f32>>, Array3<bool>), BirliError> {
     trace!("start context_to_jones_array");
 
@@ -319,10 +322,27 @@ pub fn context_to_jones_array(
     let num_baselines = context.metafits_context.num_baselines;
 
     let shape = (num_timesteps, num_chans, num_baselines);
+    let num_elems = num_timesteps * num_chans * num_baselines;
 
-    let mut jones_array: Array3<Jones<f32>> = Array3::from_elem(shape, Jones::default());
+    // We need this many gibibytes to do processing (visibilities and flags).
+    let need_gib = (shape.0 * shape.1 * shape.2)
+        * (std::mem::size_of::<Jones<f32>>() + std::mem::size_of::<bool>())
+        / 1024_usize.pow(3);
 
-    let mut flag_array: Array3<bool> = if let Some(flag_array_) = flag_array {
+    let mut jones_array = {
+        let mut v = Vec::new();
+        match v.try_reserve_exact(shape.0 * shape.1 * shape.2) {
+            Ok(()) => {
+                // Make the vector's length equal to its new capacity.
+                v.resize(num_elems, Jones::default());
+                Array3::from_shape_vec(shape, v).unwrap()
+            }
+            // Instead of erroring out with how many GiB we need for *this*
+            // array, error out with how many we need total.
+            Err(_) => return Err(BirliError::InsufficientMemory { need_gib }),
+        }
+    };
+    let mut flag_array = if let Some(flag_array_) = flag_array {
         if flag_array_.dim() != shape {
             return Err(BirliError::BadArrayShape {
                 argument: "flag_array".to_string(),
@@ -333,7 +353,16 @@ pub fn context_to_jones_array(
         };
         flag_array_
     } else {
-        Array3::from_elem(shape, false)
+        let mut v = Vec::new();
+        match v.try_reserve_exact(shape.0 * shape.1 * shape.2) {
+            Ok(()) => {
+                v.resize(num_elems, false);
+                Array3::from_shape_vec(shape, v).unwrap()
+            }
+            // Instead of erroring out with how many GiB we need for *this*
+            // array, error out with how many we need total.
+            Err(_) => return Err(BirliError::InsufficientMemory { need_gib }),
+        }
     };
 
     // since we are using read_by_by basline into buffer, the visibilities are read in order:
@@ -346,8 +375,14 @@ pub fn context_to_jones_array(
     // A queue of errors
     let (tx_error, rx_error) = unbounded();
 
+    let draw_target = if draw_progress {
+        ProgressDrawTarget::stderr()
+    } else {
+        ProgressDrawTarget::hidden()
+    };
+
     // a progress bar containing the progress bars associated with this method
-    let multi_progress = MultiProgress::with_draw_target(ProgressDrawTarget::stderr());
+    let multi_progress = MultiProgress::with_draw_target(draw_target);
     // a vector of progress bars for the visibility reading progress of each channel.
     let read_progress: Vec<ProgressBar> = mwalib_coarse_chan_range
         .to_owned()
@@ -632,6 +667,7 @@ mod tests {
             &img_coarse_chan_range,
             // img_baseline_idxs.as_slice(),
             None,
+            false,
         )
         .unwrap();
         let jones_array = jones_array.mapv(TestJones::from);
@@ -752,6 +788,7 @@ mod tests {
             &img_coarse_chan_range,
             // img_baseline_idxs.as_slice(),
             None,
+            false,
         )
         .unwrap();
 
@@ -857,6 +894,7 @@ mod tests {
             &img_coarse_chan_range,
             // img_baseline_idxs.as_slice(),
             None,
+            false,
         )
         .unwrap();
 
